diff src/toolbar-msw.c @ 380:8626e4521993 r21-2-5

Import from CVS: tag r21-2-5
author cvs
date Mon, 13 Aug 2007 11:07:10 +0200
parents 70ad99077275
children 74fd4e045ea6
line wrap: on
line diff
--- a/src/toolbar-msw.c	Mon Aug 13 11:06:08 2007 +0200
+++ b/src/toolbar-msw.c	Mon Aug 13 11:07:10 2007 +0200
@@ -87,7 +87,7 @@
   /* hmm what do we generate an id based on */
   int id = TOOLBAR_ITEM_ID_BITS (internal_hash (button->callback, 0));
   while (!NILP (Fgethash (make_int (id),
-			  FRAME_MSWINDOWS_TOOLBAR_HASHTABLE (f), Qnil)))
+			  FRAME_MSWINDOWS_TOOLBAR_HASH_TABLE (f), Qnil)))
     {
       id = TOOLBAR_ITEM_ID_BITS (id + 1);
     }
@@ -105,14 +105,14 @@
     {
       TBBUTTON info;
       
       /* delete the buttons and remove the command from the hashtable*/
       i = SendMessage (toolbarwnd, TB_BUTTONCOUNT, 0, 0);
       for (i--; i >= 0; i--)
 	{
 	  SendMessage (toolbarwnd, TB_GETBUTTON, (WPARAM)i, 
 		       (LPARAM)&info);
 	  Fremhash(make_int(info.idCommand), 
-		   FRAME_MSWINDOWS_TOOLBAR_HASHTABLE(f));
+		   FRAME_MSWINDOWS_TOOLBAR_HASH_TABLE(f));
 	  SendMessage (toolbarwnd, TB_DELETEBUTTON, (WPARAM)i, 0);
 	}
 	  
@@ -262,7 +262,7 @@
 		  
 		  if (IMAGE_INSTANCE_PIXMAP_TYPE_P (p))
 		    {
-		      /* we are going to honour the toolbar settings
+		      /* we are going to honor the toolbar settings
 			 and resize the bitmaps accordingly if they are
 			 too big.  If they are too small we leave them
 			 and pad the difference - unless a different size
@@ -293,7 +293,7 @@
 			    {
 			      xfree (button_tbl);
 			      if (ilist) ImageList_Destroy (ilist);
-			      signal_simple_error ("couldn't resize pixmap", 
+			      signal_simple_error ("Couldn't resize pixmap", 
 						   instance);
 			    }
 			  /* we don't care if the mask fails */
@@ -316,7 +316,7 @@
 					nbuttons, nbuttons * 2 )))
 			{
 			  xfree (button_tbl);
-			  signal_simple_error ("couldn't create image list",
+			  signal_simple_error ("Couldn't create image list",
 					       instance);
 			}
 
@@ -343,7 +343,7 @@
 		}
 
 	      Fputhash (make_int (tbbutton->idCommand), 
-			button, FRAME_MSWINDOWS_TOOLBAR_HASHTABLE (f));
+			button, FRAME_MSWINDOWS_TOOLBAR_HASH_TABLE (f));
 	    }
 
 	  /* now fix up the button size */
@@ -582,7 +582,7 @@
 mswindows_get_toolbar_button_text ( struct frame* f, int command_id )
 {
   Lisp_Object button = Fgethash (make_int (command_id),
-				 FRAME_MSWINDOWS_TOOLBAR_HASHTABLE (f), Qnil);
+				 FRAME_MSWINDOWS_TOOLBAR_HASH_TABLE (f), Qnil);
   
   if (!NILP (button))
     {
@@ -605,7 +605,7 @@
   Lisp_Object button, data, fn, arg, frame;
 
   button = Fgethash (make_int (id), 
-		     FRAME_MSWINDOWS_TOOLBAR_HASHTABLE (f), Qnil);
+		     FRAME_MSWINDOWS_TOOLBAR_HASH_TABLE (f), Qnil);
 
   if (NILP (button))
     return Qnil;
@@ -105,14 +105,14 @@
       TBBUTTON info;
       
-      /* delete the buttons and remove the command from the hashtable*/
+      /* Delete the buttons and remove the command from the hash table*/
       i = SendMessage (toolbarwnd, TB_BUTTONCOUNT, 0, 0);
       for (i--; i >= 0; i--)